@@ -219,6 +219,8 @@ class BaroboCtx():
   CMD_SETMOTORSTATES = 0x81
   CMD_SETGLOBALACCEL = 0x82
   CMD_PING = 0x89
+  CMD_GET_HW_REV = 0x8A
+  CMD_SET_HW_REV = 0x8B
 
   MOTOR_FORWARD = 1
   MOTOR_BACKWARD = 2
